@@ -104,8 +104,8 @@ create_prefs_menu (const PrefsEntry *menu_description,
 
 		translated_string = gettext (entry->string);
 		item = gtk_radio_menu_item_new_with_label (group, translated_string);
-		group = gtk_radio_menu_item_group (GTK_RADIO_MENU_ITEM (item));
-		gtk_menu_append (GTK_MENU (menu), item);
+		group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (item));
+		gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
 
 		g_object_set_data (G_OBJECT (item), "value", GINT_TO_POINTER (i));
 		g_object_set_data (G_OBJECT (item), "gconf_key", key);
@@ -117,8 +117,8 @@ create_prefs_menu (const PrefsEntry *menu_description,
 			history = i;
 		}
 
-		gtk_signal_connect (GTK_OBJECT (item), "activate",
-				    (GtkSignalFunc) activate_cb, view);
+		g_signal_connect (item, "activate",
+				  G_CALLBACK (activate_cb), view);
 
 		i++;
 
@@ -131,12 +131,29 @@ create_prefs_menu (const PrefsEntry *menu_description,
 	return omenu;
 }
 
+static GtkWidget*
+create_label (gchar *text,
+	      GtkWidget *widget)
+{
+	GtkWidget *alignment;
+	GtkWidget *label;
+
+	label = gtk_label_new_with_mnemonic (text);
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), widget);
+	alignment = gtk_alignment_new (1.0, 0.5, 0.0, 0.0);
+	
+	gtk_container_add (GTK_CONTAINER (alignment), label);
+
+	return alignment;
+}
+
 GtkWidget *
 eog_create_preferences_page (EogImageView *image_view,
 			     guint page_number)
 {
 	GtkWidget *table, *interp, *dither;
 	GtkWidget *check_type, *check_size;
+	GtkWidget *label;
 	GConfClient *client;
 
 	g_return_val_if_fail (image_view != NULL, NULL);
@@ -151,8 +168,9 @@ eog_create_preferences_page (EogImageView *image_view,
 				    GCONF_EOG_VIEW_INTERP_TYPE,
 				    image_view);
 
+	label = create_label (_("_Interpolation:"), interp);
 	gtk_table_attach_defaults (GTK_TABLE (table),
-				   gtk_label_new (_("Interpolation")),
+				   label,
 				   0, 1, 0, 1);
 
 	gtk_table_attach_defaults (GTK_TABLE (table), interp,
@@ -162,8 +180,9 @@ eog_create_preferences_page (EogImageView *image_view,
 				    GCONF_EOG_VIEW_DITHER,
 				    image_view);
 
+	label = create_label (_("_Dither:"), dither);
 	gtk_table_attach_defaults (GTK_TABLE (table),
-				   gtk_label_new (_("Dither")),
+				   label,
 				   0, 1, 1, 2);
 
 	gtk_table_attach_defaults (GTK_TABLE (table), dither,
@@ -173,8 +192,9 @@ eog_create_preferences_page (EogImageView *image_view,
 					GCONF_EOG_VIEW_CHECK_TYPE,
 					image_view);
 
+	label = create_label (_("Check _type:"), check_type);
 	gtk_table_attach_defaults (GTK_TABLE (table),
-				   gtk_label_new (_("Check Type")),
+				   label,
 				   0, 1, 2, 3);
 
 	gtk_table_attach_defaults (GTK_TABLE (table), check_type,
@@ -184,12 +204,17 @@ eog_create_preferences_page (EogImageView *image_view,
 					GCONF_EOG_VIEW_CHECK_SIZE,
 					image_view);
 
+	label = create_label (_("Check _size:"), check_size);
 	gtk_table_attach_defaults (GTK_TABLE (table),
-				   gtk_label_new (_("Check Size")),
+				   label,
 				   0, 1, 3, 4);
 
 	gtk_table_attach_defaults (GTK_TABLE (table), check_size,
 				   1, 2, 3, 4);
 
+	gtk_table_set_row_spacings (GTK_TABLE (table), 4);
+	gtk_table_set_col_spacings (GTK_TABLE (table), 4);
+	gtk_container_set_border_width (GTK_CONTAINER (table), 10);
+
 	return table;
 }
